==> mindstudio_probe-1.2.1-py3-none-any.whl: msprobe/docs/01.installation.md <==
# 安装

推荐使用 [miniconda](https://docs.anaconda.com/miniconda/) 管理环境依赖。

```bash
conda create -n msprobe python
conda activate msprobe
```

## 1 从 PyPI 安装
```shell
pip install mindstudio-probe
```

## 2 下载 whl 包安装

|版本|发布日期|支持 PyTorch 版本|支持 MindSpore 版本|下载链接|校验码|
|:--:|:--:|:--:|:--:|:--:|:--:|
|1.2.0|2025.1.13|1.11/2.0/2.1/2.2|2.4.0|[mindstudio_probe-1.2.0-py3-none-any.whl](https://ptdbg.obs.myhuaweicloud.com/msprobe/1.2/mindstudio_probe-1.2.0-py3-none-any.whl)|1e3aeea1706112f6ee52fd1165037936bb209138f0b9ec42ea21e2c1c8942cdc|
|1.1.1|2024.12.09|1.11/2.0/2.1/2.2|2.4.0|[mindstudio_probe-1.1.1-py3-none-any.whl](https://ptdbg.obs.myhuaweicloud.com/msprobe/1.1/mindstudio_probe-1.1.1-py3-none-any.whl)|577b597555dc155b76ba1a62d575c3546004644e140a456c3ba0824d46283735|
|1.1.0|2024.10.14|1.11/2.0/2.1/2.2|2.4.0|[mindstudio_probe-1.1.0-py3-none-any.whl](https://ptdbg.obs.myhuaweicloud.com/msprobe/1.1/mindstudio_probe-1.1.0-py3-none-any.whl)|83a5a9b7c65a357639f8c9636d88c693b4cf0eb590d4f8f5cb56395ba69b1f6d|
|1.0.4|2024.09.09|1.11/2.0/2.1/2.2|2.4.0|[mindstudio_probe-1.0.4-py3-none-any.whl](https://ptdbg.obs.myhuaweicloud.com/msprobe/1.0/mindstudio_probe-1.0.4-py3-none-any.whl)|4e1909566a71a855b356597750c20ee43d964a22b2c2b02ac08312a5def75fd6|
| 1.0.3 | 2024.08.23 | 1.11/2.0/2.1/2.2 | 2.4.0 | [mindstudio_probe-1.0.3-py3-none-any.whl](https://ptdbg.obs.myhuaweicloud.com/msprobe/1.0/mindstudio_probe-1.0.3-py3-none-any.whl) | 7060cc141a5b98ef770cd9220995d299393f32a61938261e632c7e8b5160bef2 |
| 1.0.2 | 2024.08.09 | 1.11/2.0/2.1/2.2 | 2.4.0 | [mindstudio_probe-1.0.2-py3-none-any.whl](https://ptdbg.obs.myhuaweicloud.com/msprobe/1.0/mindstudio_probe-1.0.2-py3-none-any.whl) | e4a980e5d98c426ce5ce9842520d9bc031d3b3de621c74b3d59414cc6e238e0e |
| 1.0.1 | 2024.07.25 | 2.0/2.1/2.2 | 2.4.0 | [mindstudio_probe-1.0.1-py3-none-any.whl](https://ptdbg.obs.myhuaweicloud.com/msprobe/1.0/mindstudio_probe-1.0.1-py3-none-any.whl) | b699e224e4d4e3bcf9412c54fa858a1ee370f0d7a2bc69cb3f1273ac14a6dc82 |


```bash
sha256sum {name}.whl # 验证whl包，若校验码一致，则whl包在下载中没有受损
```

```bash
pip install ./mindstudio_probe-{version}-py3-none-any.whl # 安装whl包
```

若覆盖安装，请在命令行末尾添加 `--force-reinstall` 参数。

## 3 从源码安装

```shell
git clone https://gitee.com/ascend/mstt.git
cd mstt/debug/accuracy_tools

pip install setuptools wheel

python setup.py bdist_wheel [--include-mod=[adump]]
cd ./dist
pip install ./mindstudio_probe*.whl
```

|参数|说明|是否必选|
|--|--|:--:|
|--include-mod|指定可选模块，可取值`adump`，表示在编whl包时加入adump模块。默认未配置该参数，表示编基础包。<br>&#8226; adump模块用于MindSpore静态图场景L2级别的dump。<br>&#8226; 仅MindSpore 2.5.0及以上版本支持adump模块。<br>&#8226; 若使用源码安装，编译环境需支持GCC 7或以上版本，和CMAKE 3.14或以上版本。<br>&#8226; 生成的whl包仅限编译时使用的python版本和处理器架构可用。|否|

# 特性变更说明

## 1.1.1

【数据采集】

- dump 支持 processgroup、namedtuple、slice 等数据类型
- MindSpore 动态图 dump 能力增强，支持 mix 模式 dump、控制 dropout 失效、支持控制区间正反向数据 dump

【精度预检】

- PyTorch 场景新增单算子 API 自动生成脚本
- MindSpore 动态图场景新增支持 multi_run_ut 多线程预检
- MindSpore 场景新增支持断点续检

【精度比对】

- 新增 MindSpore 跨框架比对能力，支持 MindSpore 与 PyTorch 跨框架比对
- 支持异常比对结果数据自动颜色标注

【无标杆比对】

- Mindspore 动态图场景支持反向过程的无标杆比对

【训练状态监控】

- 新增支持通信聚合前梯度信息监控

【分级可视化构图比对】

- 新增分级可视化构图比对工具，支持单数据构图、溢出检测、双数据比对构图、同时支持传入映射文件，支持跨框架或同框架比对

## 1.1.0

【总体】

- 训练精度一体化工具 atat 统一更名为 msprobe
- msprobe 支持日志分级功能

【数据采集】

- 增加 L1 dump 接口，支持在指定区间内进行正反向 dump 功能
- 新增 MindSpore 函数式接口的通信 API dump 功能

【精度预检】

- 支持配置 blacklist 黑名单字段
- 补充了支持的融合算子列表

【精度比对】

- 支持 data mapping 和 layer mapping 的比对功能。

【梯度工具】

- 增加了梯度工具中关于 JIT 限制的说明

## 1.0.4

【数据采集】

- 支持在 config.json 中传入 step 范围配置
- 优化了 MindSpore 场景下的 step 机制，step 结束后训练继续运行

【精度预检】

- 在 PyTorch 场景下，支持部分 NPU 融合算子精度预检

【精度比对】

- 解决了在 MindSpore 场景下需要安装 PyTorch 的问题

【无标杆比对】

- 补充了 PyTorch 场景的性能基线报告
- 支持 MindSpore 场景下的 change_value 扰动模式

## 1.0.3

【精度预检】

- 落盘数据缩减
- 支持随机生成模式和真实数据模式
- 单 API 测试，排除整网中的累计误差问题

【梯度检测】

- 使用便捷，无需在训练流程里插入代码
- 可以精准定位问题出现的 step

# 查看 msprobe 工具信息

```bash
pip show mindstudio-probe
```

示例如下：

```bash
Name: mindstudio-probe
Version: 1.0.x
Summary: Pytorch Ascend Probe Utils
Home-page: https://gitee.com/ascend/mstt/tree/master/debug/accuracy_tools/msprobe
Author: Ascend Team
Author-email: pmail_mindstudio@huawei.com
License: Apache License 2.0
Location: /home/xxx/miniconda3/envs/xxx/lib/python3.x/site-packages/mindstudio_probe-1.0.x-py3.x.egg
Requires: einops, matplotlib, numpy, openpyxl, pandas, pyOpenSSL, pyyaml, rich, tqdm, twisted, wheel
Required-by: 
```

# Ascend 生态链接

## 1 安装 CANN 包

1.1 根据 CPU 架构和 NPU 型号选择 toolkit 和 kernel，可以参考 [CANN 软件安装指南](https://gitee.com/link?target=https%3A%2F%2Fwww.hiascend.com%2Fdocument%2Fdetail%2Fzh%2Fcanncommercial%2F700%2Fenvdeployment%2Finstg%2Finstg_0001.html)和[昇腾社区](https://www.hiascend.cn/developer/download/community/result?module=cann)。

1.2 运行示例
```bash
Ascend-cann-toolkit_x.x.x_linux-xxxx.run --full --install-path={cann_path}
Ascend-cann-kernels_x.x.x_linux.run --install --install-path={cann_path}
```

1.3 配置环境变量
```bash
source {cann_path}/ascend-toolkit/set_env.sh
```
## 2 安装 PyTorch_NPU 

链接：[https://gitee.com/ascend/pytorch](https://gitee.com/ascend/pytorch)。

## 3 安装 ModelLink

链接：[https://gitee.com/ascend/ModelLink](https://gitee.com/ascend/ModelLink)。

==> mindstudio_probe-1.3.0-py3-none-any.whl: msprobe/docs/01.installation.md <==
# 安装

推荐使用 [miniconda](https://docs.anaconda.com/miniconda/) 管理环境依赖。

```bash
conda create -n msprobe python
conda activate msprobe
```

## 1 从 PyPI 安装
```shell
pip install mindstudio-probe
```

## 2 下载 whl 包安装

|版本|发布日期|支持 PyTorch 版本|支持 MindSpore 版本|下载链接|校验码|
|:--:|:--:|:--:|:--:|:--:|:--:|
|1.2.2|2025.3.03|1.11/2.0/2.1/2.2|2.4.0|[mindstudio_probe-1.2.2-py3-none-any.whl](https://ptdbg.obs.myhuaweicloud.com/msprobe/1.2/mindstudio_probe-1.2.2-py3-none-any.whl)|961411bb460d327ea51d6ca4d0c8e8c5565f07c0852d7b8592b781ca35b87212|
|1.2.1|2025.2.07|1.11/2.0/2.1/2.2|2.4.0|[mindstudio_probe-1.2.1-py3-none-any.whl](https://ptdbg.obs.myhuaweicloud.com/msprobe/1.2/mindstudio_probe-1.2.1-py3-none-any.whl)|b64b342118558e0339b39237f88a49b93fd24551b0cb202c872fbfef4260c86b|
|1.2.0|2025.1.13|1.11/2.0/2.1/2.2|2.4.0|[mindstudio_probe-1.2.0-py3-none-any.whl](https://ptdbg.obs.myhuaweicloud.com/msprobe/1.2/mindstudio_probe-1.2.0-py3-none-any.whl)|1e3aeea1706112f6ee52fd1165037936bb209138f0b9ec42ea21e2c1c8942cdc|
|1.1.1|2024.12.09|1.11/2.0/2.1/2.2|2.4.0|[mindstudio_probe-1.1.1-py3-none-any.whl](https://ptdbg.obs.myhuaweicloud.com/msprobe/1.1/mindstudio_probe-1.1.1-py3-none-any.whl)|577b597555dc155b76ba1a62d575c3546004644e140a456c3ba0824d46283735|
|1.1.0|2024.10.14|1.11/2.0/2.1/2.2|2.4.0|[mindstudio_probe-1.1.0-py3-none-any.whl](https://ptdbg.obs.myhuaweicloud.com/msprobe/1.1/mindstudio_probe-1.1.0-py3-none-any.whl)|83a5a9b7c65a357639f8c9636d88c693b4cf0eb590d4f8f5cb56395ba69b1f6d|
|1.0.4|2024.09.09|1.11/2.0/2.1/2.2|2.4.0|[mindstudio_probe-1.0.4-py3-none-any.whl](https://ptdbg.obs.myhuaweicloud.com/msprobe/1.0/mindstudio_probe-1.0.4-py3-none-any.whl)|4e1909566a71a855b356597750c20ee43d964a22b2c2b02ac08312a5def75fd6|
| 1.0.3 | 2024.08.23 | 1.11/2.0/2.1/2.2 | 2.4.0 | [mindstudio_probe-1.0.3-py3-none-any.whl](https://ptdbg.obs.myhuaweicloud.com/msprobe/1.0/mindstudio_probe-1.0.3-py3-none-any.whl) | 7060cc141a5b98ef770cd9220995d299393f32a61938261e632c7e8b5160bef2 |
| 1.0.2 | 2024.08.09 | 1.11/2.0/2.1/2.2 | 2.4.0 | [mindstudio_probe-1.0.2-py3-none-any.whl](https://ptdbg.obs.myhuaweicloud.com/msprobe/1.0/mindstudio_probe-1.0.2-py3-none-any.whl) | e4a980e5d98c426ce5ce9842520d9bc031d3b3de621c74b3d59414cc6e238e0e |
| 1.0.1 | 2024.07.25 | 2.0/2.1/2.2 | 2.4.0 | [mindstudio_probe-1.0.1-py3-none-any.whl](https://ptdbg.obs.myhuaweicloud.com/msprobe/1.0/mindstudio_probe-1.0.1-py3-none-any.whl) | b699e224e4d4e3bcf9412c54fa858a1ee370f0d7a2bc69cb3f1273ac14a6dc82 |


```bash
sha256sum {name}.whl # 验证whl包，若校验码一致，则whl包在下载中没有受损
```

```bash
pip install ./mindstudio_probe-{version}-py3-none-any.whl # 安装whl包
```

若覆盖安装，请在命令行末尾添加 `--force-reinstall` 参数。

## 3 从源码安装

```shell
git clone https://gitee.com/ascend/mstt.git
cd mstt/debug/accuracy_tools

pip install setuptools wheel

python setup.py bdist_wheel [--include-mod=[adump]]
cd ./dist
pip install ./mindstudio_probe*.whl
```

|参数|说明|是否必选|
|--|--|:--:|
|--include-mod|指定可选模块，可取值`adump`，表示在编whl包时加入adump模块。默认未配置该参数，表示编基础包。<br>&#8226; adump模块用于MindSpore静态图场景L2级别的dump。<br>&#8226; 仅MindSpore 2.5.0及以上版本支持adump模块。<br>&#8226; 若使用源码安装，编译环境需支持GCC 7.5或以上版本，和CMAKE 3.14或以上版本。<br>&#8226; 生成的whl包仅限编译时使用的python版本和处理器架构可用。|否|

# 特性变更说明

## 1.2.0

【数据采集】

- 模块级dump支持采集权重及权重梯度
- 修复原地覆盖类API前向输入数据采集不正确的问题
- seed_all接口支持控制dropout失效功能

【精度预检】

- MindSpore场景新增支持Tensor类的mint API的预检

【训练状态监控】

- 支持FSDP和ZeRO-0
- 异常排序支持前向激活值和反向梯度

【分级可视化构图比对】

- 支持graph结构分页展示，支持graph批量构建和比对
- 支持溢出检测模式

## 1.1.1

## 1.1.1

【数据采集】

- dump 支持 processgroup、namedtuple、slice 等数据类型
- MindSpore 动态图 dump 能力增强，支持 mix 模式 dump、控制 dropout 失效、支持控制区间正反向数据 dump

【精度预检】

- PyTorch 场景新增单算子 API 自动生成脚本
- MindSpore 动态图场景新增支持 multi_run_ut 多线程预检
- MindSpore 场景新增支持断点续检

【精度比对】

- 新增 MindSpore 跨框架比对能力，支持 MindSpore 与 PyTorch 跨框架比对
- 支持异常比对结果数据自动颜色标注

【无标杆比对】

- Mindspore 动态图场景支持反向过程的无标杆比对

【训练状态监控】

- 新增支持通信聚合前梯度信息监控

【分级可视化构图比对】

- 新增分级可视化构图比对工具，支持单数据构图、溢出检测、双数据比对构图、同时支持传入映射文件，支持跨框架或同框架比对

## 1.1.0

【总体】

- 训练精度一体化工具 atat 统一更名为 msprobe
- msprobe 支持日志分级功能

【数据采集】

- 增加 L1 dump 接口，支持在指定区间内进行正反向 dump 功能
- 新增 MindSpore 函数式接口的通信 API dump 功能

【精度预检】

- 支持配置 blacklist 黑名单字段
- 补充了支持的融合算子列表

【精度比对】

- 支持 data mapping 和 layer mapping 的比对功能。

【梯度工具】

- 增加了梯度工具中关于 JIT 限制的说明

## 1.0.4

【数据采集】

- 支持在 config.json 中传入 step 范围配置
- 优化了 MindSpore 场景下的 step 机制，step 结束后训练继续运行

【精度预检】

- 在 PyTorch 场景下，支持部分 NPU 融合算子精度预检

【精度比对】

- 解决了在 MindSpore 场景下需要安装 PyTorch 的问题

【无标杆比对】

- 补充了 PyTorch 场景的性能基线报告
- 支持 MindSpore 场景下的 change_value 扰动模式

## 1.0.3

【精度预检】

- 落盘数据缩减
- 支持随机生成模式和真实数据模式
- 单 API 测试，排除整网中的累计误差问题

【梯度检测】

- 使用便捷，无需在训练流程里插入代码
- 可以精准定位问题出现的 step

# 查看 msprobe 工具信息

```bash
pip show mindstudio-probe
```

示例如下：

```bash
Name: mindstudio-probe
Version: 1.0.x
Summary: Pytorch Ascend Probe Utils
Home-page: https://gitee.com/ascend/mstt/tree/master/debug/accuracy_tools/msprobe
Author: Ascend Team
Author-email: pmail_mindstudio@huawei.com
License: Apache License 2.0
Location: /home/xxx/miniconda3/envs/xxx/lib/python3.x/site-packages/mindstudio_probe-1.0.x-py3.x.egg
Requires: einops, matplotlib, numpy, openpyxl, pandas, pyOpenSSL, pyyaml, rich, tqdm, twisted, wheel
Required-by: 
```

# Ascend 生态链接

## 1 安装 CANN 包

1.1 根据 CPU 架构和 NPU 型号选择 toolkit 和 kernel，可以参考 [CANN 软件安装指南](https://gitee.com/link?target=https%3A%2F%2Fwww.hiascend.com%2Fdocument%2Fdetail%2Fzh%2Fcanncommercial%2F700%2Fenvdeployment%2Finstg%2Finstg_0001.html)和[昇腾社区](https://www.hiascend.cn/developer/download/community/result?module=cann)。

1.2 运行示例
```bash
Ascend-cann-toolkit_x.x.x_linux-xxxx.run --full --install-path={cann_path}
Ascend-cann-kernels_x.x.x_linux.run --install --install-path={cann_path}
```

1.3 配置环境变量
```bash
source {cann_path}/ascend-toolkit/set_env.sh
```
## 2 安装 PyTorch_NPU 

链接：[https://gitee.com/ascend/pytorch](https://gitee.com/ascend/pytorch)。

## 3 安装 ModelLink

链接：[https://gitee.com/ascend/ModelLink](https://gitee.com/ascend/ModelLink)。
